@@ -4,7 +4,7 @@ from pydecidim.api.decidim_connector import DecidimConnector
 from pydecidim.api.participatory_process_reader import ParticipatoryProcessReader
 from pydecidim.model.participatory_process import ParticipatoryProcess
 
-QUERY_PATH = "https://meta.decidim.org/api"
+QUERY_PATH = "https://www.decidim.barcelona/api"
 
 
 class ParticipatoryProcessesReaderTest(unittest.TestCase):
@@ -17,7 +17,7 @@ class ParticipatoryProcessesReaderTest(unittest.TestCase):
     def test_execute(self):
         decidim_connector: DecidimConnector = DecidimConnector(QUERY_PATH)
         reader: ParticipatoryProcessReader = ParticipatoryProcessReader(decidim_connector, base_path="../..")
-        participatory_process = reader.execute("40")  # We use the participatory process #40 on Decidim.org api.
+        participatory_process = reader.execute("5")  # We use the participatory process #40 on Decidim.org api.
         self.assertIsInstance(participatory_process, ParticipatoryProcess)
 
 
